@@ -15,11 +15,11 @@ import (
 
 	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
 	manifestworkv1 "github.com/open-cluster-management/api/work/v1"
-	agentv1 "github.com/open-cluster-management/klusterlet-addon-controller/pkg/apis/agent/v1"
-	addons "github.com/open-cluster-management/klusterlet-addon-controller/pkg/components"
-	appmgr "github.com/open-cluster-management/klusterlet-addon-controller/pkg/components/appmgr/v1"
-	certpolicyctrl "github.com/open-cluster-management/klusterlet-addon-controller/pkg/components/certpolicycontroller/v1"
-	iampolicyctrl "github.com/open-cluster-management/klusterlet-addon-controller/pkg/components/iampolicycontroller/v1"
+	agentv1 "github.com/stolostron/klusterlet-addon-controller/pkg/apis/agent/v1"
+	addons "github.com/stolostron/klusterlet-addon-controller/pkg/components"
+	appmgr "github.com/stolostron/klusterlet-addon-controller/pkg/components/appmgr/v1"
+	certpolicyctrl "github.com/stolostron/klusterlet-addon-controller/pkg/components/certpolicycontroller/v1"
+	iampolicyctrl "github.com/stolostron/klusterlet-addon-controller/pkg/components/iampolicycontroller/v1"
 	ocinfrav1 "github.com/openshift/api/config/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -58,11 +58,11 @@ func Test_syncManifestWorkCRs(t *testing.T) {
 			Kind:       "ConfigMap",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      "test-configmap-2.3.5",
+			Name:      "test-configmap-2.3.6",
 			Namespace: "test-namespace",
 			Labels: map[string]string{
 				"ocm-configmap-type":  "image-manifest",
-				"ocm-release-version": "2.3.5",
+				"ocm-release-version": "2.3.6",
 			},
 		},
 		Data: map[string]string{
@@ -627,7 +627,7 @@ func Test_updateManagedClusterAddon(t *testing.T) {
 				t.Errorf("updateManagedClusterAddon() error = %v, wantErr %v", err, tt.wantErr)
 				return
 			} else if err == nil && !tt.wantErr {
-				//get it should succeed
+				// get it should succeed
 				getMca := &addonv1alpha1.ManagedClusterAddOn{}
 				getErr := tt.args.client.Get(context.TODO(),
 					types.NamespacedName{
